import {Request, Response} from 'express';
import {reportError} from '../../core/utils';
import db from '../../core/db';

export default async (req: Request, res: Response) => {
    try {
        const result = await db.map(
            `
                SELECT DISTINCT unnest(tags) AS tag
                FROM wikidot_pages
                WHERE wiki_name = $(wiki);`,
            {wiki: 'scp-ru'},
            (result) => result.tag);
        res.send(result.sort((one, another) => one.localeCompare(another)));
    } catch(error) {
        res.status(500).send('Unhandled internal error, incident reported');
        reportError(error, {tags: {location: 'wikidot/tags-list'}});
    }
};
