import pino from './pino';
import Sentry = require('raven');
import {Request, Response, NextFunction} from 'express';

const SENTRY_DSN = process.env.SENTRY_DSN;

interface SentryClient {
    captureException(error: Error, args: any): void;
    captureMessage(): void;
    requestHandler(): (req: Request, res: Response, next: NextFunction) => void;
    errorHandler(): (err: Error, req: Request, res: Response, next: NextFunction) => void;
}

let sentry;

if (SENTRY_DSN) {
    Sentry.config(SENTRY_DSN).install();
    sentry = Sentry;
    sentry.captureException = sentry.captureException.bind(sentry);
    sentry.captureMessage = sentry.captureMessage.bind(sentry);
} else {
    sentry = {
        captureException: () => {},
        captureMessage: () => {},
        requestHandler: () => (req: Request, res: Response, next: NextFunction) => next(),
        errorHandler: () => (err: Error, req: Request, res: Response, next: NextFunction) => next(err)
    };
}

export default <SentryClient> sentry;
