import db from './db';
import pino from './pino';
import sentry from './sentry';
import * as Queue from 'bee-queue';
import * as Discord from 'discord.js';

const discord = new Discord.Client();
let logChannel: any;
discord.on('ready', () => {
    logChannel = discord.channels
        .find('id', process.env.DISCORD_LOG_CHANNEL_ID);
});
discord.login(process.env.DISCORD_BOT_TOKEN);

type LogLineArgs = {
    extra?: Object;
    message?: string;
    tags?: {[key: string]: string};
};

export function log(message: string, args?: LogLineArgs): void {
    if (args && args.extra) {
        pino.info(args.extra, message);
    } else {
        pino.info(message);
    }
}

export function reportError(error: Error, args?: LogLineArgs): void {
    const callArgs: any[] = [error];
    if (args) {
        if (args.message) {
            callArgs.push(args.message);
        }
        if (args.extra) {
            callArgs.push(args.extra);
        }
    }
    pino.error.apply(pino, callArgs);
    sentry.captureException(error, args);
}

const queue = new Queue('common', {
    isWorker: false
});

export async function enqueue(
    type: string,
    args: Array<string|number|boolean>,
    timeout: number = 30000,
    retries: number = 2
) {
    try {
        await queue.createJob({type, args})
            .timeout(timeout)
            .retries(retries)
            .save();
    } catch (error) {
        reportError(error, {message: 'Failed to enqueue job', extra: {type, args}});
    }
}

export function logToDiscord(message: string) {
    if (logChannel) {
        log(`[DiscordLogger] ${message}`);
        logChannel.send(message);
    } else {
        log(`DiscordLogger is not ready (failed to send message: "${message}")`);
    }
}
