import {log, logToDiscord, reportError} from '../core/utils';
import * as Discord from 'discord.js';
import WikidotUser from '../models/wikidot-user';
const discord = new Discord.Client();
const token = process.env.DISCORD_BOT_TOKEN;

const SCP_RU_GUILD_ID = '106464299056128000';
const MEMBERS_ROLE_ID = '106465861476319232';

export function run() {
    return new Promise((resolve) => {
        discord.on('ready', () => {
            const guild = discord.guilds.find((data, key) => key === SCP_RU_GUILD_ID);
            const memberRole = guild.roles.find((role) => {
                return role.id === MEMBERS_ROLE_ID;
            });

            let numberOfMembersToSync: number;
            WikidotUser.findMembersWithDiscordTag()
                .then((memberDiscordIDs: Array<string>) => {
                    numberOfMembersToSync = memberDiscordIDs.length;
                    return guild.members.filterArray((member) => {
                        const user = member.user;
                        const userID = `${user.username}#${user.discriminator}`;
                        return memberDiscordIDs.includes(userID);
                    });
                })
                .map((userToUpdate: any) => {
                    return userToUpdate.addRole(memberRole);
                })
                .then(() => {
                    log(`Synced discord roles for ${numberOfMembersToSync} members`);
                    resolve();
                })
                .catch((error: Error) => {
                    reportError(error, {message: 'Error setting discord member roles'});
                    resolve();
                });
        });
        discord.login(token);
    })
}
