import db from '../core/db';
import {log, reportError} from '../core/utils';
import * as cheerio from 'cheerio';
import {wk, SITES_LIST} from '../components/wikidot-kit';
import Bluebird = require("bluebird");

const OBJECT_TITLE_REGEXP = /^SCP/;

// TODO This task should be refactored to support list of wiki sites instead of one EN branch

type ObjectItem = {name: string, title: string};

export function run() {
    log('Performing EN object titles extraction');

    const wikiName = 'scp-wiki';
    const pageNames = ['scp-series', 'scp-series-2', 'scp-series-3', 'joke-scps', 'archived-scps', 'scp-ex'];

    const promises = [];

    return (db.map(`
        SELECT html
        FROM wikidot_pages
        WHERE
          wiki_name = $(wikiName) AND name IN ($(pageNames:csv))
    `, {wikiName, pageNames}, page => page.html) as any)

        .reduce((result: string, pageHtml: string) => result + pageHtml, '')

        .then((html: string) => {
            const $ = cheerio.load(html);
            return Array.from($('li')).reduce((objects: ObjectItem[], line) => {
                const text = $(line).text();
                if (OBJECT_TITLE_REGEXP.test(text)) {
                    objects.push({
                        name: text.split(' - ')[0].toLowerCase(),
                        title: text
                    });
                }
                return objects;
            }, []);
        })

        .map((object: {name: string, title: string}) => {
            return db.none(`
            UPDATE wikidot_pages
            SET title = $(title)
            WHERE wiki_name = 'scp-wiki' AND name = $(name);
        `, object);
        }, {concurrency: 4})

        .catch((error: Error) => {
            reportError(error, {message: 'Error extraction object titles'});
        });
}
