import db from '../core/db';
import {log, reportError} from '../core/utils';
import {wk, SITES_LIST} from '../components/wikidot-kit';

export function run() {
    log('Performing pages lists import');

    const promises = SITES_LIST
        .filter(({interwiki}) => interwiki)
        .map(site => {
            const siteName = site.name;
            return wk.fetchPagesList(siteName)
                .then(list => {
                    return db.query(`
                        INSERT INTO wikidot_pages_lists (wiki_name, data)
                        VALUES($(siteName), $(list))
                        ON CONFLICT (wiki_name) DO UPDATE SET
                            data = $(list)
                    `, {siteName, list: {list}}).then(() => {
                        log(`Pages list for wiki ${siteName} updated`);
                    });
                })
                .catch(error => {
                    reportError(error, {extra: {siteName}});
                });
        });

    return Promise.all(promises);
}
