"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../../core/utils");
const db_1 = require("../../core/db");
exports.default = async (req, res) => {
    const wiki = req.query.wiki;
    const tags = Array.isArray(req.query.tag) ? req.query.tag : [req.query.tag];
    if (wiki && tags) {
        try {
            const result = await db_1.default.query(`
                SELECT id, name, title, tags as all_tags
                FROM wikidot_pages
                WHERE wiki_name = $(wiki) AND $(tags) :: TEXT [] <@ tags;
            `, { wiki, tags });
            res.send(result);
        }
        catch (error) {
            res.status(500).send('Unhandled internal error, incident reported');
            utils_1.reportError(error, { tags: { location: 'wikidot/tags-search' } });
        }
    }
    else {
        res.status(400).send({ error: 'Wiki or tags are not specified' });
    }
};
//# sourceMappingURL=tags-search.js.map