"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pino_1 = require("./pino");
const sentry_1 = require("./sentry");
const Queue = require("bee-queue");
const Discord = require("discord.js");
const discord = new Discord.Client();
let logChannel;
discord.on('ready', () => {
    logChannel = discord.channels
        .find('id', process.env.DISCORD_LOG_CHANNEL_ID);
});
discord.login(process.env.DISCORD_BOT_TOKEN);
function log(message, args) {
    if (args && args.extra) {
        pino_1.default.info(args.extra, message);
    }
    else {
        pino_1.default.info(message);
    }
}
exports.log = log;
function reportError(error, args) {
    const callArgs = [error];
    if (args) {
        if (args.message) {
            callArgs.push(args.message);
        }
        if (args.extra) {
            callArgs.push(args.extra);
        }
    }
    pino_1.default.error.apply(pino_1.default, callArgs);
    sentry_1.default.captureException(error, args);
}
exports.reportError = reportError;
const queue = new Queue('common', {
    isWorker: false
});
async function enqueue(type, args, timeout = 30000, retries = 2) {
    try {
        await queue.createJob({ type, args })
            .timeout(timeout)
            .retries(retries)
            .save();
    }
    catch (error) {
        reportError(error, { message: 'Failed to enqueue job', extra: { type, args } });
    }
}
exports.enqueue = enqueue;
function logToDiscord(message) {
    if (logChannel) {
        log(`[DiscordLogger] ${message}`);
        logChannel.send(message);
    }
    else {
        log(`DiscordLogger is not ready (failed to send message: "${message}")`);
    }
}
exports.logToDiscord = logToDiscord;
//# sourceMappingURL=utils.js.map