"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../core/db");
const utils_1 = require("../core/utils");
const cheerio = require("cheerio");
const OBJECT_TITLE_REGEXP = /^SCP/;
function run() {
    utils_1.log('Performing EN object titles extraction');
    const wikiName = 'scp-wiki';
    const pageNames = ['scp-series', 'scp-series-2', 'scp-series-3', 'joke-scps', 'archived-scps', 'scp-ex'];
    const promises = [];
    return db_1.default.map(`
        SELECT html
        FROM wikidot_pages
        WHERE
          wiki_name = $(wikiName) AND name IN ($(pageNames:csv))
    `, { wikiName, pageNames }, page => page.html)
        .reduce((result, pageHtml) => result + pageHtml, '')
        .then((html) => {
        const $ = cheerio.load(html);
        return Array.from($('li')).reduce((objects, line) => {
            const text = $(line).text();
            if (OBJECT_TITLE_REGEXP.test(text)) {
                objects.push({
                    name: text.split(' - ')[0].toLowerCase(),
                    title: text
                });
            }
            return objects;
        }, []);
    })
        .map((object) => {
        return db_1.default.none(`
            UPDATE wikidot_pages
            SET title = $(title)
            WHERE wiki_name = 'scp-wiki' AND name = $(name);
        `, object);
    }, { concurrency: 4 })
        .catch((error) => {
        utils_1.reportError(error, { message: 'Error extraction object titles' });
    });
}
exports.run = run;
//# sourceMappingURL=object-titles-extraction.js.map