"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../core/db");
const utils_1 = require("../core/utils");
const wikidot_kit_1 = require("../components/wikidot-kit");
function run(wikiName, pageName) {
    utils_1.log(`Importing page ${wikiName}/${pageName}`);
    const wikiUrl = wikidot_kit_1.SITES[wikiName].url;
    return wikidot_kit_1.wk.fetchPage(wikiName, pageName)
        .catch((error) => {
        utils_1.reportError(error, { message: 'Error importing page', extra: { wikiName, pageName } });
    })
        .then((data) => {
        return db_1.default.query(`
                INSERT INTO wikidot_pages (
                  wiki_name,
                  name,
                  title,
                  tags,
                  rating,
                  content,
                  html,
                  created_at,
                  created_by,
                  updated_at,
                  updated_by
                )
                VALUES (
                  $(wikiName),
                  $(pageName),
                  $(title),
                  $(tags),
                  $(rating),
                  $(content),
                  $(html),
                  $(createdAt),
                  $(createdBy),
                  $(updatedAt),
                  $(updatedBy)
                )
                ON CONFLICT (name, wiki_name) DO UPDATE SET
                  title = $(title),
                  tags = $(tags)::text[],
                  rating = $(rating),
                  content = $(content),
                  html = $(html),
                  created_at = $(createdAt),
                  created_by = $(createdBy),
                  updated_at = $(updatedAt),
                  updated_by = $(updatedBy);
            `, {
            wikiName,
            pageName,
            createdAt: data.created_at,
            createdBy: data.created_by,
            updatedAt: data.updated_at,
            updatedBy: data.updated_by,
            title: data.title,
            tags: data.tags,
            rating: data.rating,
            content: data.content,
            html: data.html
        });
    })
        .then(() => {
        return wikidot_kit_1.wk.fetchPageVotes(wikiUrl, pageName);
    })
        .then(votes => {
        return db_1.default.query(`
                INSERT INTO wikidot_pages (wiki_name, name, votes) VALUES ($(wikiName), $(pageName), $(votes))
                ON CONFLICT (wiki_name, name) DO UPDATE SET votes = $(votes);
            `, {
            wikiName,
            pageName,
            votes: { votes }
        });
    })
        .then(() => {
        utils_1.log(`[DONE] ${wikiName}/${pageName}`);
    })
        .catch((error) => {
        utils_1.reportError(error, { message: 'Error saving page', extra: { wikiName, pageName } });
    });
}
exports.run = run;
//# sourceMappingURL=page-import.js.map