"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../core/db");
const utils_1 = require("../core/utils");
const wikidot_kit_1 = require("../components/wikidot-kit");
function run() {
    utils_1.log('Performing pages lists import');
    const promises = wikidot_kit_1.SITES_LIST
        .filter(({ interwiki }) => interwiki)
        .map(site => {
        const siteName = site.name;
        return wikidot_kit_1.wk.fetchPagesList(siteName)
            .then(list => {
            return db_1.default.query(`
                        INSERT INTO wikidot_pages_lists (wiki_name, data)
                        VALUES($(siteName), $(list))
                        ON CONFLICT (wiki_name) DO UPDATE SET
                            data = $(list)
                    `, { siteName, list: { list } }).then(() => {
                utils_1.log(`Pages list for wiki ${siteName} updated`);
            });
        })
            .catch(error => {
            utils_1.reportError(error, { extra: { siteName } });
        });
    });
    return Promise.all(promises);
}
exports.run = run;
//# sourceMappingURL=pages-lists-import.js.map